# OctoBot-Services [1.2.0](https://github.com/Drakkar-Software/OctoBot-Services/tree/master/docs/CHANGELOG.md)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/31a1caa6e5384d80bf890dba5c9b5e4b)](https://app.codacy.com/gh/Drakkar-Software/OctoBot-Services?utm_source=github.com&utm_medium=referral&utm_content=Drakkar-Software/OctoBot-Services&utm_campaign=Badge_Grade_Dashboard)
[![PyPI](https://img.shields.io/pypi/v/OctoBot-Services.svg)](https://pypi.python.org/pypi/OctoBot-Services/)
[![Build Status](https://api.travis-ci.com/Drakkar-Software/OctoBot-Services.svg?branch=master)](https://travis-ci.com/Drakkar-Software/OctoBot-Services) 
[![Build Status](https://dev.azure.com/drakkarsoftware/OctoBot-Services/_apis/build/status/Drakkar-Software.OctoBot-Services?branchName=master)](https://dev.azure.com/drakkarsoftware/OctoBot-Services/_build/latest?definitionId=6&branchName=master)

OctoBot services package.
